// ////////////////////////////////////////////////////
//
// StdView.h : interface of the CStdView class
// Based on class COGLView : public CView
// Inspect COGLView for standard OpenGL initialization
//
////////////////////////////////////////////////////////
#include "oglview.h"
#define PCNT 80

class CStdView : public COGLView
{
protected: 
	CStdView();
	DECLARE_DYNCREATE(CStdView)

	// store precalculated bezier functions
	// weight functions for function, derivative and double derivative
	GLfloat btab[4][PCNT];
	GLfloat d_btab[4][PCNT];
	GLfloat dd_btab[4][PCNT];

	// control points
	v3d bgp0,bgp1,bgp2,bgp3;

	// last axes
	v3d oldN,oldC,oldB;


	// tabulating function values
	GLfloat bez[PCNT][3];

	// tabulating derivative function values
	GLfloat d_bez[PCNT][3];
	
	// tabulating double derivative function values
	GLfloat dd_bez[PCNT][3];

	// mousing around
	CPoint last_p;
	GLfloat vx,vy;
	BOOL is_moving;

	int showix,stepix;

	// options
	BOOL bShowCylinders;
	BOOL bAnimate;
	BOOL bShowAxes;
	BOOL bRun;
	BOOL bDrawBezier;


	void drawBezier();
	void makeBezier(v3d p0,v3d p1,v3d p2,v3d p3);
	void make_d_Bezier(v3d p0,v3d p1,v3d p2,v3d p3);
	void make_dd_Bezier(v3d p0,v3d p1,v3d p2,v3d p3);


// Operations
public:
	CStdDoc* GetDocument();
	virtual void DrawScene();
	virtual void InitializeRContext();
	virtual void SetPerspective(int cx, int cy);

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CStdView)
	//}}AFX_VIRTUAL

// Implementation
public:
	virtual ~CStdView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
	//{{AFX_MSG(CStdView)
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnShowCylinders();
	afx_msg void OnUpdateShowCylinders(CCmdUI* pCmdUI);
	afx_msg void OnShowAnimation();
	afx_msg void OnUpdateShowAnimation(CCmdUI* pCmdUI);
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnShowAxes();
	afx_msg void OnUpdateShowAxes(CCmdUI* pCmdUI);
	afx_msg void OnShowRun();
	afx_msg void OnUpdateShowRun(CCmdUI* pCmdUI);
	afx_msg void OnShowBezier();
	afx_msg void OnUpdateShowBezier(CCmdUI* pCmdUI);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#ifndef _DEBUG  // debug version in StdView.cpp
inline CStdDoc* CStdView::GetDocument()
   { return (CStdDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////
